@@ -2,17 +2,21 @@ import abc
 from typing import Optional
 
 
-class EncryptionProvider(abc.ABC):
+class DecryptionProvider(abc.ABC):
+    """Abstract DecryptionProvider."""
+    @abc.abstractmethod
+    def decrypt(self, data: str) -> Optional[str]:
+        """Tries to decrypt Base64-encoded string and return plaintext or None."""
+
+
+class EncryptionProvider(DecryptionProvider):
     """Abstract EncryptionProvider."""
     @abc.abstractmethod
     def encrypt(self, data: str) -> str:
         """Encrypts data and returns an Base64-encoded string"""
-        pass
-
-    @abc.abstractmethod
-    def decrypt(self, data: str) -> Optional[str]:
-        """Tries to decrypt Base64-encoded string and return plaintext or None."""
-        pass
 
 
+from .secretbox import SecretBox
+from .secretbox import MultiSecretBox
+from .secretbox import MultiSecretDecryptor
 from .passwordsecretbox import PasswordSecretBox
